# Table of Contents

- [discovering-ai-agents-using-api](<./discovering-ai-agents-using-api.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Uploading AI Agents Through the API](<./Uploading-AI-Agents-Through-the-API.md>)
  - [Overview](<./Uploading-AI-Agents-Through-the-API/Overview.md>)
  - [Prerequisites](<./Uploading-AI-Agents-Through-the-API/Prerequisites.md>)
  - [Activating the API](<./Uploading-AI-Agents-Through-the-API/Activating-the-API.md>)
  - [Authentication](<./Uploading-AI-Agents-Through-the-API/Authentication.md>)
  - [Endpoint](<./Uploading-AI-Agents-Through-the-API/Endpoint.md>)
  - [API Request](<./Uploading-AI-Agents-Through-the-API/API-Request.md>)
  - [Linking Discovered Items to Fact Sheets](<./Uploading-AI-Agents-Through-the-API/Linking-Discovered-Items-to-Fact-Sheets.md>)
  - [Viewing Synchronization Logs](<./Uploading-AI-Agents-Through-the-API/Viewing-Synchronization-Logs.md>)
  - [Deactivating the API](<./Uploading-AI-Agents-Through-the-API/Deactivating-the-API.md>)
